==> peitho_data-1.1.2.tar.gz: peitho_data-1.1.2/README.md <==
<div align="center">

<a href="https://www.bilibili.com/video/BV1kb4y1m7e7?p=3">
    <img alt="永恒" src="./theme/韶光抚月-天下人间.png">
    Raiden Shogun (雷电将军), the character of eternity, themes my never-ending focus on data in general
</a>

<br>
<br>

[ ![PyPI](https://img.shields.io/pypi/v/peitho-data?logo=pypi&logoColor=white&style=for-the-badge) ](https://pypi.org/project/peitho-data/)
[ ![Read the Docs (version)](https://img.shields.io/readthedocs/peitho-data/latest?logo=Read%20the%20Docs&logoColor=white&style=for-the-badge) ](https://peitho-data.readthedocs.io/en/latest/)
[ ![GitHub Workflow Status](https://img.shields.io/github/workflow/status/QubitPi/peitho-data/Release?logo=github&style=for-the-badge) ](https://github.com/QubitPi/peitho-data/actions/workflows/release.yml)

[ ![Discord](https://img.shields.io/discord/1005754525942030366?logo=discord&logoColor=white&style=for-the-badge) ](https://discord.com/widget?id=1005754525942030366&theme=dark)
[ ![Project Management](https://img.shields.io/badge/Project%20Management-0052CC?style=for-the-badge&logo=trello&logoColor=white) ](https://trello.com/b/ersqV9rd)
[![License Badge](https://img.shields.io/badge/Apache%202.0-F25910.svg?style=for-the-badge&logo=Apache&logoColor=white) ](https://www.apache.org/licenses/LICENSE-2.0)
![GitHub last commit (branch)](https://img.shields.io/github/last-commit/QubitPi/peitho-data/master?logo=github&style=for-the-badge)

[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=bugs)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Duplicated Lines (%)](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=duplicated_lines_density)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=coverage)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Lines of Code](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=ncloc)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
</div>

<div align="right">

[![SonarCloud](https://sonarcloud.io/images/project_badges/sonarcloud-orange.svg)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)

</div>


What is Peitho Data
-------------------

<a href="https://www.bilibili.com/video/BV1kb4y1m7e7?p=3">
    <img align="right" width="50%" alt="永恒" src="./theme/永恒.gif">
</a>

[Peitho Data](https://qubitpi.github.io/peitho-data/) is an opinionated **data analytics** package that team can
leverage to quickly incorporate capabilities of

* Data Analytics/Visualization
* Machine Learning
* AI


Documentation
-------------

<img src="./theme/雷电将军.png" alt="雷电将军.png" width="5%"></img>
[Start exploring Peitho Data](https://qubitpi.github.io/peitho-data/)


License
-------

The use and distribution terms for [Peitho Data](https://qubitpi.github.io/peitho-data/) are covered by the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0.html).

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://user-images.githubusercontent.com/16126939/186319317-601c8d28-84dd-4e24-ab56-881ddd7933b5.png">
    </a>
</div>

==> peitho_data-2.3.0.tar.gz: peitho_data-2.3.0/README.md <==
<div align="center">

<a href="https://www.bilibili.com/video/BV1kb4y1m7e7?p=3">
    <img alt="永恒" src="./theme/韶光抚月-天下人间.png">
    Raiden Shogun (雷电将军), the character of eternity, themes my never-ending focus on data in general
</a>

<br>
<br>

[![PyPI](https://img.shields.io/pypi/v/peitho-data?logo=pypi&logoColor=white&style=for-the-badge)](https://pypi.org/project/peitho-data/)
[![Read the Docs (version)](https://img.shields.io/readthedocs/peitho-data/latest?logo=Read%20the%20Docs&logoColor=white&style=for-the-badge)](https://peitho-data.readthedocs.io/en/latest/)
[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/QubitPi/peitho-data/ci-cd.yml?logo=github&style=for-the-badge)](https://github.com/QubitPi/peitho-data/actions/workflows/ci-cd.yml)

[![Discord](https://img.shields.io/discord/1005754525942030366?logo=discord&logoColor=white&style=for-the-badge)](https://discord.com/widget?id=1005754525942030366&theme=dark)
[![License Badge](https://img.shields.io/badge/Apache%202.0-F25910.svg?style=for-the-badge&logo=Apache&logoColor=white)](https://www.apache.org/licenses/LICENSE-2.0)
![GitHub last commit (master)](https://img.shields.io/github/last-commit/QubitPi/peitho-data/master?logo=github&style=for-the-badge)

[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=bugs)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Duplicated Lines (%)](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=duplicated_lines_density)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=coverage)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Lines of Code](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=ncloc)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=QubitPi_peitho-data&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)
</div>

<div align="right">

[![SonarCloud](https://sonarcloud.io/images/project_badges/sonarcloud-orange.svg)](https://sonarcloud.io/summary/new_code?id=QubitPi_peitho-data)

</div>


What is Peitho Data <sup>![Python Version Badge is Missing](https://img.shields.io/badge/Python-3.10-brightgreen?style=flat-square&logo=python&logoColor=white)</sup>
-------------------

<a href="https://www.bilibili.com/video/BV1kb4y1m7e7?p=3">
    <img align="right" width="50%" alt="永恒" src="./theme/永恒.gif">
</a>

[Peitho Data](https://peitho-data.readthedocs.io/en/latest/) is an opinionated **data analytics** package that team can
leverage to quickly incorporate capabilities of

* Data Analytics/Visualization
* Machine Learning
* AI


Documentation
-------------

<img src="./theme/雷电将军.png" alt="雷电将军.png" width="5%"></img>
[Start exploring Peitho Data](https://peitho-data.readthedocs.io/en/latest/)


License
-------

The use and distribution terms for [Peitho Data](https://peitho-data.readthedocs.io/en/latest/) are covered by the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0.html).

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://github.com/QubitPi/QubitPi/blob/master/img/apache-2.png?raw=true">
    </a>
</div>
